#
# spec file for package perl-Minion
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Minion
Name:           perl-Minion
Version:        10.300.0
Release:        1.2
# 10.30 -> normalize -> 10.300.0
%define cpan_version 10.30
License:        Artistic-2.0
Summary:        Job queue
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SR/SRI/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Mojolicious) >= 9.0
BuildRequires:  perl(YAML::XS) >= 0.67
Requires:       perl(Mojolicious) >= 9.0
Requires:       perl(YAML::XS) >= 0.67
Provides:       perl(Minion) = %{version}
Provides:       perl(Minion::Backend)
Provides:       perl(Minion::Backend::Pg)
Provides:       perl(Minion::Command::minion)
Provides:       perl(Minion::Command::minion::job)
Provides:       perl(Minion::Command::minion::worker)
Provides:       perl(Minion::Iterator)
Provides:       perl(Minion::Job)
Provides:       perl(Minion::Worker)
Provides:       perl(Mojolicious::Plugin::Minion)
Provides:       perl(Mojolicious::Plugin::Minion::Admin)
%undefine       __perllib_provides
%{perl_requires}

%description
Minion is a high performance job queue for the Perl programming language,
with support for multiple named queues, priorities, high priority fast
lane, delayed jobs, job dependencies, job progress, job results, retries
with backoff, rate limiting, unique jobs, expiring jobs, statistics,
distributed workers, parallel processing, autoscaling, remote control, at
https://mojolicious.org admin ui, resource leak protection and multiple
backends (such as at https://www.postgresql.org).

Job queues allow you to process time and/or computationally intensive tasks
in background processes, outside of the request/response lifecycle of web
applications. Among those tasks you'll commonly find image resizing, spam
filtering, HTTP downloads, building tarballs, warming caches and basically
everything else you can imagine that's not super fast.

Take a look at our excellent documentation in Minion::Guide!

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README.md
%license LICENSE

%changelog
* Sun Jun 23 2024 Tina Müller <tina.mueller@suse.com>
- updated to 10.300.0 (10.30)
  see /usr/share/doc/packages/perl-Minion/Changes
  10.30 2024-06-05
  - Improved stats performance in Minion::Backend::Pg by an order of magnitude. (rshingleton)
* Fri Mar 22 2024 Tina Müller <timueller+perl@suse.de>
- updated to 10.29
  see /usr/share/doc/packages/perl-Minion/Changes
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Wed Nov 29 2023 Tina Müller <timueller+perl@suse.de>
- updated to 10.28
  see /usr/share/doc/packages/perl-Minion/Changes
  10.28  2023-11-217
  - Improved repair and history performance in most cases.
  10.27  2023-11-20
  - Improved repair performance in cases where there are a lot of finished jobs with dependencies.
* Sat Nov 11 2023 Tina Müller <timueller+perl@suse.de>
- updated to 10.26
  see /usr/share/doc/packages/perl-Minion/Changes
  10.26  2023-11-10
  - Added type information to worker status.
  - Improved workers by calling srand() after starting a new job process.
* Sat Jun 25 2022 Tina Müller <timueller+perl@suse.de>
- updated to 10.25
  see /usr/share/doc/packages/perl-Minion/Changes
  10.25  2022-06-24
  - Added workers field to stats methods in Minion and Minion::Backend::Pg.
* Fri Apr 29 2022 Tina Müller <timueller+perl@suse.de>
- updated to 10.24
  see /usr/share/doc/packages/perl-Minion/Changes
  10.24  2022-04-28
  - Improved Mojolicious::Plugin::Minion::Admin to log whenever a job gets removed.
* Fri Jan 21 2022 Tina Müller <timueller+perl@suse.de>
- updated to 10.23
  see /usr/share/doc/packages/perl-Minion/Changes
  10.23  2022-01-20
  - Improved repair performance in Minion::Backend::Pg. (andrii-suse, ilmari, kraih)
* Fri Jun 11 2021 Tina Müller <timueller+perl@suse.de>
- updated to 10.22
  see /usr/share/doc/packages/perl-Minion/Changes
  10.22  2021-06-10
  - Add perform_jobs_in_foreground method to Minion.
* Sun Mar 21 2021 Tina Müller <timueller+perl@suse.de>
- updated to 10.21
  see /usr/share/doc/packages/perl-Minion/Changes
  10.21  2021-03-20
  - Fixed YAML::XS dependency.
* Mon Mar 15 2021 Tina Müller <timueller+perl@suse.de>
- updated to 10.20
  see /usr/share/doc/packages/perl-Minion/Changes
  10.20  2021-03-13
  - Removed experimental status from expiring jobs feature.
  - Added Minion::Guide.
  - Improved admin ui and job command to use YAML::XS to make job information easier to read.
* Thu Mar 11 2021 Tina Müller <timueller+perl@suse.de>
- updated to 10.19
  see /usr/share/doc/packages/perl-Minion/Changes
  10.19  2021-03-10
  - Improved admin ui to include search feature on all pages.
* Wed Mar 10 2021 Tina Müller <timueller+perl@suse.de>
- updated to 10.18
  see /usr/share/doc/packages/perl-Minion/Changes
  10.18  2021-03-09
  - Improved admin ui with search feature.
* Sun Mar  7 2021 Tina Müller <timueller+perl@suse.de>
- updated to 10.17
  see /usr/share/doc/packages/perl-Minion/Changes
  10.17  2021-03-05
  - Added support for high priority fast lane.
  - Added each method to Minion::Iterator.
  - Added min_priority option to dequeue methods in Minion::Worker and Minion::Backend::Pg.
  - Added spare and spare_min_priority options to run method in Minion::Worker.
  - Added -s and -S options to worker command.
  - Added --retry-failed and --remove-failed options to job command.
* Wed Feb 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 10.16
  see /usr/share/doc/packages/perl-Minion/Changes
  10.16  2021-02-16
  - Fixed Mojolicious 9.0 compatibility.
* Mon Jan  4 2021 Tina Müller <timueller+perl@suse.de>
- updated to 10.15
  see /usr/share/doc/packages/perl-Minion/Changes
  10.15  2020-12-10
  - Updated examples to use signatures.
* Mon Oct 26 2020 Tina Müller <timueller+perl@suse.de>
- updated to 10.14
  see /usr/share/doc/packages/perl-Minion/Changes
  10.14  2020-10-24
  - Changed SQL style to use uppercase keywords.
  - Fixed a bug where Minion::Worker could inherit timers from Mojolicious applications.
* Sat Aug  1 2020 Tina Müller <timueller+perl@suse.de>
- updated to 10.13
  see /usr/share/doc/packages/perl-Minion/Changes
  10.13  2020-07-30
  - Added EXPERIMENTAL support for lax dependencies.
  - Added EXPERIMENTAL lax option to enqueue method in Minion, Minion::Backend and Minion::Backend::Pg.
  - Removed experimental status from notes option in Minion::Backend and Minion::Backend::Pg.
  - Added lax field to list_jobs method in Minion::Backend::Pg.
  - Added is_locked method to Minion.
  - Added auto_retry_job method to Minion::Backend.
  - Added parents method to Minion::Job.
  - Added -x option to job command.
  - Fixed a bug in Minion::Backend::Pg where manual retries would count towards the attempts limit for automatic
    retries.
* Tue Jul 28 2020 Tina Müller <timueller+perl@suse.de>
- updated to 10.12
  see /usr/share/doc/packages/perl-Minion/Changes
  10.12  2020-07-25
  - Added EXPERIMENTAL support for expiring jobs.
  - Removed experimental support for job sequences again since use cases turned out to be weaker than expected.
  - Added EXPERIMENTAL expire option to enqueue method in Minion, Minion::Backend and Minion::Backend::Pg.
  - Added expires field to list_jobs method in Minion::Backend::Pg.
  - Added -E option to job command.
  10.11  2020-07-21
  - Improved adming ui with more icons.
* Sun Jul 12 2020 Tina Müller <timueller+perl@suse.de>
- updated to 10.10
  see /usr/share/doc/packages/perl-Minion/Changes
  10.10  2020-07-11
  - Added stuck_after attribute to Minion.
  - Improved repair method in Minion::Backend::Pg to detect stuck jobs and transtion them to the failed state after 2
    days of inactivity.
* Fri Jul 10 2020 Tina Müller <timueller+perl@suse.de>
- updated to 10.09
  see /usr/share/doc/packages/perl-Minion/Changes
  10.09  2020-07-09
  - Added EXPERIMENTAL support for job sequences.
  - Added EXPERIMENTAL sequence option to enqueue method in Minion, Minion::Backend and Minion::Backend::Pg.
  - Added EXPERIMENTAL sequences option to list_jobs method in Minion::Backend and Minion::Backend::Pg.
  - Added next and previous fields to list_jobs method in Minion::Backend::Pg.
  - Added -Q option to job command.
  - Improved admin ui to allow navigating job sequences.
* Thu Jun 18 2020 Tina Müller <timueller+perl@suse.de>
- updated to 10.08
  see /usr/share/doc/packages/perl-Minion/Changes
  10.08  2020-06-17
  - Improved Minion::Job to record exit code and the signal a job died from, if it was terminated unexpectedly.
* Wed Jun 17 2020 Tina Müller <timueller+perl@suse.de>
- updated to 10.07
  see /usr/share/doc/packages/perl-Minion/Changes
  10.07  2020-06-16
  - Removed experimental status from Minion::Iterator module.
  - Removed experimental status from jobs and workers methods in Minion.
  - Removed experimental status from before options of list_jobs and list_workers methods in Minion::Backend and
    Minion::Backend::Pg.
  - Updated project metadata.
  - Improved admin ui to allow sending TERM signals.
  - Fixed a bug in Minion::Job where CHLD, INT, TERM and QUIT signals would be ignored by job processes.
* Wed Jun  3 2020 Tina Müller <timueller+perl@suse.de>
- updated to 10.06
  see /usr/share/doc/packages/perl-Minion/Changes
  10.06  2020-06-01
  - Added EXPERIMENTAL support for custom task classes.
  - Added EXPERIMENTAL class_for_task method to Minion.
  - Added EXPERIMENTAL run method to Minion::Job.
  - Added -T option to job command.
* Mon Jun  1 2020 Tina Müller <timueller+perl@suse.de>
  updated to 10.05
  see /usr/share/doc/packages/perl-Minion/Changes
  10.05  2020-05-30
  - Improved .perltidyrc with more modern settings.
  - Fixed result_p promise leak in Minion.
* Fri Jan 31 2020 <timueller+perl@suse.de>
- updated to 10.04
  see /usr/share/doc/packages/perl-Minion/Changes
  10.04  2020-01-30
  - Added EXPERIMENTAL total method to Minion::Iterator.
  10.03  2020-01-29
  - Added EXPERIMENTAL Minion::Iterator module.
  - Added EXPERIMENTAL jobs and workers methods to Minion.
  - Added EXPERIMENTAL before options to list_jobs and list_workers methods in
    Minion::Backend and Minion::Backend::Pg.
* Sat Dec 21 2019 <timueller+perl@suse.de>
- updated to 10.02
  see /usr/share/doc/packages/perl-Minion/Changes
  10.02  2019-12-20
  - Fixed QUIT signal in Minion::Worker.
  - Fixed stop remote control command.
  - Fixed a problem where Minion::Worker was unable to deal with immediately
    restarted jobs.
* Tue Dec 17 2019 <timueller+perl@suse.de>
- updated to 10.01
  see /usr/share/doc/packages/perl-Minion/Changes
  10.01  2019-12-16
  - Fixed an unlock concurrency issue in Minion::Backend::Pg.
* Tue Nov 19 2019 <timueller+perl@suse.de>
- updated to 10.0
  see /usr/share/doc/packages/perl-Minion/Changes
  10.0  2019-11-15
  - Removed PostgreSQL migrations older than 2 years, that means you need to
    have Minion version 7.01 or newer installed before you can upgrade to
    version 10.0.
  - Removed experimental status from result_p method in Minion.
  - Removed experimental status from history method in Minion and
    Minion::Backend::Pg.
  - Removed experimental status from delayed_jobs and enqueued_jobs fields from
    stats methods in Minion and Minion::Backend::Pg.
  - Removed experimental status from cleanup and finish events in Minion::Job.
  - Changed reset method in Minion and Minion::Backend::Pg to require options
    for what to reset.
  - Improved reset method in Minion and Minion::Backend::Pg to allow for locks
    to be reset without resetting the whole queue.
  - Improved performance by making the minion_workers table unlogged.
* Fri Aug 30 2019 <timueller+perl@suse.de>
- updated to 9.13
  see /usr/share/doc/packages/perl-Minion/Changes
  9.13  2019-08-29
  - Added EXPERIMENTAL cleanup event to Minion::Job.
* Tue Aug  6 2019 Stephan Kulow <coolo@suse.com>
- updated to 9.12
  see /usr/share/doc/packages/perl-Minion/Changes
  9.12  2019-08-04
  - Added EXPERIMENTAL notes option to list_jobs method in Minion::Backend and
    Minion::Backend::Pg.
  - Added -n option to job command.
  - Improved note methods in Minion::Job, Minion::Backend and
    Minion::Backend::Pg to allow for fields to be removed.
* Tue Jul 16 2019 Stephan Kulow <coolo@suse.com>
- updated to 9.11
  see /usr/share/doc/packages/perl-Minion/Changes
  9.11  2019-07-08
  - Added time field to list_jobs method in Minion::Backend::Pg.
  - Added time field to info method in Minion::Job.
  - Improved admin ui to show the current runtime for every job, as well as the
    current delay for delayed jobs.
  - Improved Minion::Backend::Pg to ignore missing workers for jobs in the
    minion_foreground named queue and make debugging very slow jobs easier.
* Tue May 14 2019 Stephan Kulow <coolo@suse.com>
- updated to 9.10
  see /usr/share/doc/packages/perl-Minion/Changes
  9.10  2019-05-09
  - Fixed a few query parameter bugs in the admin ui. (fskale, sri)
* Mon Feb  4 2019 Stephan Kulow <coolo@suse.com>
- updated to 9.09
  see /usr/share/doc/packages/perl-Minion/Changes
  9.09  2019-02-03
  - Changed result_p method in Minion to pass along the whole job info hash
    instead of just the job result.
* Sun Feb  3 2019 Stephan Kulow <coolo@suse.com>
- updated to 9.08
  see /usr/share/doc/packages/perl-Minion/Changes
  9.08  2019-02-01
  - Added EXPERIMENTAL result_p method to Minion.
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 9.07
  see /usr/share/doc/packages/perl-Minion/Changes
  9.07  2018-10-18
  - Improved various attributes to use new Mojolicious 8.03 features to avoid
    memory leaks.
* Sun Sep 23 2018 Stephan Kulow <coolo@suse.com>
- updated to 9.06
  see /usr/share/doc/packages/perl-Minion/Changes
  9.06  2018-09-22
  - Added support for controlling job processes by installing signal handlers
    for INT, USR1 and USR2 in tasks.
  - Added kill method to Minion::Job.
  - Improved worker command with support for kill remote control command.
  - Improved admin ui with a new menu to send signals to job processes.
* Sat Sep 22 2018 Stephan Kulow <coolo@suse.com>
- updated to 9.05
  see /usr/share/doc/packages/perl-Minion/Changes
* Sat Apr 21 2018 coolo@suse.com
- updated to 9.03
  see /usr/share/doc/packages/perl-Minion/Changes
* Thu Apr 19 2018 coolo@suse.com
- updated to 9.02
  see /usr/share/doc/packages/perl-Minion/Changes
* Mon Apr 16 2018 coolo@suse.com
- updated to 9.0
  see /usr/share/doc/packages/perl-Minion/Changes
  9.0  2018-04-15
  - Replaced queue, state and task options of list_jobs method in
    Minion::Backend::Pg with queues, states and tasks options.
  - Replaced name option of list_locks method in Minion::Backend::Pg with names
    option.
  - Replaced key/value argument of note method in Minion::Backend::Pg with a
    hash reference.
  - Added EXPERIMENTAL support for displaying a 24 hour history graph on the
    Mojolicious::Plugin::Minion::Admin dashboard.
  - Added EXPERIMENTAL finish event to Minion::Job.
  - Added EXPERIMENTAL history methods to Minion and Minion::Backend::Pg.
  - Added execute method to Minion::Job.
  - Added -H option to job command.
  - Improved note method in Minion::Job to allow for multiple metadata fields to
    be changed at once.
  - Fixed a bug where the job command could remove all parents from retried
    jobs.
  - Fixed filtering of jobs by queue and state in
    Mojolicious::Plugin::Minion::Admin.
* Thu Mar  8 2018 coolo@suse.com
- updated to 8.12
  see /usr/share/doc/packages/perl-Minion/Changes
  8.12  2018-03-07
  - Added parents option to retry and retry_job methods in Minion::Job and
    Minion::Backend::Pg. (CandyAngel)
* Thu Mar  1 2018 coolo@suse.com
- updated to 8.11
  see /usr/share/doc/packages/perl-Minion/Changes
  8.11  2018-02-28
  - Fixed worker page links in Mojolicious::Plugin::Minion::Admin.
* Mon Feb 19 2018 coolo@suse.com
- updated to 8.10
  see /usr/share/doc/packages/perl-Minion/Changes
* Wed Feb  7 2018 coolo@suse.com
- updated to 8.09
  see /usr/share/doc/packages/perl-Minion/Changes
  8.09  2018-01-25
  - Converted Mojolicious::Plugin::Minion::Admin to Bootstrap 4.
* Mon Dec 18 2017 coolo@suse.com
- updated to 8.08
  see /usr/share/doc/packages/perl-Minion/Changes
  8.08  2017-12-15
  - Added busy and wait events to Minion::Worker.
  - Added dequeue_timeout option to run method in Minion::Worker.
  - Added -D option to worker command.
* Tue Dec 12 2017 coolo@suse.com
- updated to 8.07
  see /usr/share/doc/packages/perl-Minion/Changes
* Thu Nov 23 2017 coolo@suse.com
- updated to 8.03
  see /usr/share/doc/packages/perl-Minion/Changes
  8.03  2017-11-21
  - Removed -f option from worker command.
  - Added broadcast method to Minion.
  - Added run method to Minion::Worker.
* Tue Nov 21 2017 coolo@suse.com
- updated to 8.02
  see /usr/share/doc/packages/perl-Minion/Changes
  8.02  2017-11-19
  - Improved admin ui with alerts for job management.
* Sun Nov 19 2017 coolo@suse.com
- updated to 8.01
  see /usr/share/doc/packages/perl-Minion/Changes
  8.01  2017-11-18
  - Fixed installation problems with some versions of Perl on Windows.
* Sat Nov 18 2017 coolo@suse.com
- updated to 8.0
  see /usr/share/doc/packages/perl-Minion/Changes
  8.0  2017-11-16
  - Removed job_info and worker_info methods from Minion::Backend and
    Minion::Backend::Pg.
  - Changed return value of list_jobs and list_workers methods in
    Minion::Backend and Minion::Backend::Pg.
  - Added new module Mojolicious::Plugin::Minion::Admin.
  - Added ids option to list_jobs and list_workers methods in Minion::Backend
    and Minion::Backend::Pg.
  - Added uptime field to stats methods in Minion, Minion::Backend and
    Minion::Backend::Pg.
* Fri Oct 27 2017 coolo@suse.com
- updated to 7.09
  see /usr/share/doc/packages/perl-Minion/Changes
  7.09  2017-10-20
  - Fixed a deadlock problem in Minion::Backend::Pg where jobs could fail if two
    processes tried to acquire the same lock at the same time.
* Thu Oct 19 2017 coolo@suse.com
- updated to 7.08
  see /usr/share/doc/packages/perl-Minion/Changes
  7.08  2017-10-18
  - Fixed a bug in the worker command where processing jobs could be
    delayed significantly after a system restart. (rgci)
* Fri Oct 13 2017 coolo@suse.com
- updated to 7.07
  see /usr/share/doc/packages/perl-Minion/Changes
  7.07  2017-10-11
  - Added reap event to Minion::Job.
* Fri Sep 22 2017 coolo@suse.com
- updated to 7.06
  see /usr/share/doc/packages/perl-Minion/Changes
  7.06  2017-09-21
  - Added guard method to Minion.
* Tue Aug  8 2017 coolo@suse.com
- updated to 7.05
  see /usr/share/doc/packages/perl-Minion/Changes
  7.05  2017-08-07
  - Improved foreground method in Minion to rethrow job exceptions.
* Wed Aug  2 2017 coolo@suse.com
- updated to 7.04
  see /usr/share/doc/packages/perl-Minion/Changes
  7.04  2017-08-01
  - Added foreground method to Minion.
  - Added id option to dequeue methods in Minion::Worker and
    Minion::Backend::Pg.
  - Added attempts option to retry and retry_job methods in Minion::Job and
    Minion::Backend::Pg.
  - Added -f option to job command.
* Sat Jul  8 2017 coolo@suse.com
- updated to 7.03
  see /usr/share/doc/packages/perl-Minion/Changes
  7.03  2017-07-06
  - Updated Mojo::Pg requirement to 4.0.
  - Improved Minion::Backend::Pg to support sharing the database connection
    cache with existing Mojo::Pg objects.
  7.02  2017-07-05
  - Improved performance of worker command when processing jobs that are
    finished very quickly.
* Mon Jun 26 2017 coolo@suse.com
- updated to 7.01
  see /usr/share/doc/packages/perl-Minion/Changes
  7.01  2017-06-25
  - Added note methods to Minion::Job and Minion::Backend::Pg.
  - Added notes option to enqueue methods in Minion and Minion::Backend::Pg.
  - Added notes field to info method in Minion::Job and job_info method in
    Minion::Backend::Pg.
  - Improved performance of stats and lock methods in Minion::Backend::Pg with a
    new index and other optimizations. (depesz)
  - Improved benchmark script to be more consistent. (depesz)
* Tue Jun 20 2017 coolo@suse.com
- updated to 7.0
  see /usr/share/doc/packages/perl-Minion/Changes
  7.0  2017-06-18
  - Added support for rate limiting and unique jobs.
  - Added lock and unlock methods to Minion and Minion::Backend::Pg.
  - Improved performance of Minion::Backend::Pg significantly with a new index
    and other optimizations.
* Fri Jun  9 2017 coolo@suse.com
- updated to 6.06
  see /usr/share/doc/packages/perl-Minion/Changes
  6.06  2017-06-03
  - Added an example application to demonstrate how to integrate background jobs
    into well-structured Mojolicious applications.
* Fri Apr  7 2017 coolo@suse.com
- updated to 6.05
  see /usr/share/doc/packages/perl-Minion/Changes
  6.05  2017-04-03
  - Added support for sharing worker status information.
  - Improved retry methods to allow for active jobs to be retried as well.
  - Improved job command to show timestamps in RFC 3339 (1994-11-06T08:49:37Z)
    format.
* Tue Mar 21 2017 coolo@suse.com
- updated to 6.04
  see /usr/share/doc/packages/perl-Minion/Changes
  6.04  2017-03-18
  - Added -f option to worker command.
  - Removed -r option from job command, so you have to write --remove from now
    on, which should prevent accidental mixups with the -R option in the future.
* Wed Mar 15 2017 coolo@suse.com
- updated to 6.03
  see /usr/share/doc/packages/perl-Minion/Changes
  6.03  2017-03-14
  - Fixed serious performance problems in Minion::Backend::Pg.
* Mon Jan  2 2017 coolo@suse.com
- updated to 6.02
  see /usr/share/doc/packages/perl-Minion/Changes
  6.02  2017-01-02
  - Updated Mojo::Pg requirement to 2.18.
  6.01  2017-01-01
  - Updated Mojo::Pg requirement to 2.33.
  - Improved performance of Minion::Backend::Pg with a new index.
* Tue Sep 20 2016 coolo@suse.com
- updated to 6.0
  see /usr/share/doc/packages/perl-Minion/Changes
  6.0  2016-09-17
  - Removed TTIN, TTOU and USR1 signals from worker command.
  - Changed return value of start method in Minion::Job.
  - Added support for worker remote control commands.
  - Added commands attribute to Minion::Worker.
  - Added add_command and process_commands methods to Minion::Worker.
  - Added pid and stop methods to Minion::Job.
  - Added broadcast and receive methods to Minion::Backend::Pg.
  - Added -b option to job command.
  - Improved worker command with support for jobs and stop remote control
    commands.
* Fri Sep  2 2016 coolo@suse.com
- updated to 5.09
  see /usr/share/doc/packages/perl-Minion/Changes
  5.09  2016-08-31
  - Added EXPERIMENTAL enqueued_jobs field to stats methods in Minion and
    Minion::Backend::Pg.
  - Improved Minion::Backend::Pg performance slightly with a new index.
* Mon May 23 2016 coolo@suse.com
- updated to 5.08
  see /usr/share/doc/packages/perl-Minion/Changes
  5.08  2016-05-20
  - Improved repair methods not to remove finished jobs with unresolved
    dependencies.
  5.07  2016-05-17
  - Added support for job dependencies. (jberger, sri)
  - Added parents option to enqueue methods in Minion and Minion::Backend::Pg.
    (jberger, sri)
  - Added children and parents fields to info method in Minion::Job and job_info
    method in Minion::Backend::Pg.
  - Added -P option to job command.
  - Improved stats methods to include jobs with unresolved dependencies in
    delayed_jobs count.
  5.06  2016-05-05
  - Improved worker command to support the TTIN, TTOU and USR1 signals.
  - Improved Minion::Backend::Pg to handle delayed and retried jobs more
    efficiently.
* Thu May  5 2016 coolo@suse.com
- updated to 5.05
  see /usr/share/doc/packages/perl-Minion/Changes
  5.05  2016-04-20
  - Added queue option to list_jobs method in Minion::Backend::Pg.
  - Improved performance of stats method in Minion::Backend::Pg slightly.
  5.04  2016-04-19
  - Added EXPERIMENTAL delayed_jobs field to stats method in Minion and
    Minion::Backend::Pg.
  - Updated Mojo::Pg requirement to 2.18.
  - Improved job command to show more detailed information for jobs and workers.
* Mon Apr 11 2016 coolo@suse.com
- updated to 5.03
  see /usr/share/doc/packages/perl-Minion/Changes
  5.03  2016-04-10
  - Added enqueue event to Minion. (jberger)
* Mon Apr  4 2016 coolo@suse.com
- updated to 5.02
  see /usr/share/doc/packages/perl-Minion/Changes
  5.02  2016-03-23
  - Fixed copyright notice.
* Tue Mar  8 2016 coolo@suse.com
- updated to 5.01
  see /usr/share/doc/packages/perl-Minion/Changes
  5.01  2016-02-24
  - Fixed worker command to repair in regular intervals.
* Fri Feb 19 2016 coolo@suse.com
- updated to 5.0
  see /usr/share/doc/packages/perl-Minion/Changes
  5.0  2016-02-17
  - Added start event to Minion::Job.
  - Added -R option to worker command.
  - Reduced default missing_after value to 30 minutes.
  - Reduced default remove_after value to 2 days.
  - Improved Minion::Backend::Pg performance significantly with a new index and
    PostgreSQL 9.5 features.
  - Improved Minion::Job to capture more exceptions.
  - Improved worker command to support the QUIT signal.
  - Improved worker command to repair in less regular intervals.
* Sun Feb  7 2016 coolo@suse.com
- updated to 4.06
  see /usr/share/doc/packages/perl-Minion/Changes
  4.06  2016-02-06
  - Improved performance of Minion::Backend::Pg slightly.
  4.05  2016-02-05
  - Improved Minion::Backend::Pg to check the PostgreSQL version.
* Wed Jan 27 2016 coolo@suse.com
- updated to 4.04
  see /usr/share/doc/packages/perl-Minion/Changes
  4.04  2016-01-23
  - Updated Minion::Backend::Pg to use new Mojo::Pg features.
* Tue Jan 19 2016 coolo@suse.com
- updated to 4.03
  see /usr/share/doc/packages/perl-Minion/Changes
  4.03  2016-01-17
  - Removed an unused index from Minion::Backend::Pg.
  - Fixed a bug where the worker command would always watch the default queue.
    (avkhozov)
* Wed Jan 13 2016 coolo@suse.com
- updated to 4.02
  see /usr/share/doc/packages/perl-Minion/Changes
  4.02  2016-01-03
  - Updated links to Mojolicious website.
* Sat Nov 14 2015 coolo@suse.com
- updated to 4.01
  see /usr/share/doc/packages/perl-Minion/Changes
  4.01  2015-11-12
  - Improved retry methods to allow options to be changed for already inactive
    jobs.
* Wed Nov 11 2015 coolo@suse.com
- updated to 4.0
  see /usr/share/doc/packages/perl-Minion/Changes
  4.0  2015-11-09
  - Removed attempts attribute from Minion::Job.
  - Improved Minion::Backend::Pg to preserve more information across retries for
    debugging.
  - Fixed bug where jobs could not be retried automatically if a worker went
    away.
* Mon Nov  9 2015 coolo@suse.com
- updated to 3.03
  see /usr/share/doc/packages/perl-Minion/Changes
  3.03  2015-11-08
  - Added queues option to perform_jobs method in Minion.
* Sat Oct 31 2015 coolo@suse.com
- updated to 3.02
  see /usr/share/doc/packages/perl-Minion/Changes
  3.02  2015-10-31
  - Fixed portability issues in tests.
  3.01  2015-10-30
  - Added support retrying failed jobs automatically.
  - Added backoff attribute to Minion.
  - Added attempts attribute to Minion::Job.
  - Added attempts option to enqueue method in Minion and Minion::Backend::Pg.
  - Added -A option to job command.
  3.0  2015-10-30
  - Removed Minion::Backend::File, because DBM::Deep quickly becomes unusably
    slow, you can use the CPAN module Minion::Backend::SQLite instead.
* Fri Oct 16 2015 coolo@suse.com
- updated to 2.05
  see /usr/share/doc/packages/perl-Minion/Changes
  2.05  2015-10-15
  - Fixed bug where jobs could sometimes not be finished correctly by the worker
    command.
  2.04  2015-10-14
  - Fixed portability issue in worker command.
* Sun Oct 11 2015 coolo@suse.com
- updated to 2.03
  see /usr/share/doc/packages/perl-Minion/Changes
  2.03  2015-10-09
  - Improved commands to show all options that can affect their behavior.
* Sat Oct 10 2015 coolo@suse.com
- updated to 2.02
  see /usr/share/doc/packages/perl-Minion/Changes
  2.02  2015-10-08
  - Improved job command to show the queue in job lists.
* Sun Oct  4 2015 coolo@suse.com
- updated to 2.01
  see /usr/share/doc/packages/perl-Minion/Changes
  2.01  2015-10-02
  - Fixed Windows portability issues in tests.
* Fri Oct  2 2015 coolo@suse.com
- updated to 2.0
  see /usr/share/doc/packages/perl-Minion/Changes
  2.0  2015-10-01
  - Removed -t option from worker command.
  - Added support for multiple named queues.
  - Added retries attribute to Minion::Job.
  - Added retries argument to fail_job, finish_job and retry_job methods in
    Minion::Backend::File and Minion::Backend::Pg.
  - Added queue option to enqueue method in Minion.
  - Added queue option to enqueue and retry_job methods in Minion::Backend::File
    and Minion::Backend::Pg.
  - Added queues option to dequeue method in Minion::Worker.
  - Added queues option to dequeue method in Minion::Backend::File and
    Minion::Backend::Pg.
  - Added -q option to job and worker commands.
  - Improved worker command to be more resilient to time jumps.
  - Fixed a race condition in Minion::Backend::File and Minion::Backend::Pg
    where a retried job did not have to be dequeued again before it could be
    finished.
  1.19  2015-09-28
  - Added support for retrying jobs with a new priority.
  - Added priority option to retry method in Minion::Job.
  - Added priority option to retry_job method in Minion::Backend::File and
    Minion::Backend::Pg.
* Thu Sep  3 2015 coolo@suse.com
- updated to 1.18
  see /usr/share/doc/packages/perl-Minion/Changes
  1.18  2015-08-30
  - Fixed Makefile.PL to be compliant with version 2 of the CPAN distribution
    metadata specification.
* Sat Aug 29 2015 coolo@suse.com
- updated to 1.17
  see /usr/share/doc/packages/perl-Minion/Changes
  1.17  2015-08-29
  - Fixed bug in worker command where new jobs would still be dequeued after
    receiving an INT/TERM signal.
  1.16  2015-08-28
  - Improved worker command to detect workers without heartbeat a little faster.
* Sat May 16 2015 coolo@suse.com
- updated to 1.15
  see /usr/share/doc/packages/perl-Minion/Changes
  1.15  2015-05-15
  - Added support for retrying jobs with a delay. (kwa)
  - Added delay option to retry method in Minion::Job. (kwa)
  - Added delay option to retry_job method in Minion::Backend::File. (kwa)
  - Added delay option to retry_job method in Minion::Backend::Pg. (kwa)
* Wed Apr 22 2015 coolo@suse.com
- updated to 1.14
  see /usr/share/doc/packages/perl-Minion/Changes
  1.14  2015-04-21
  - Improved performance of Minion::Backend::Pg with a new index. (avkhozov)
* Fri Mar 27 2015 coolo@suse.com
- initial package 1.13
  * created by cpanspec 1.78.08
